%define softname  libQGLViewer
%define packname  qglviewer

%define major     2
%define docname   %{name}-doc

Name:		libqglviewer
Summary:	Qt based OpenGL generic 3D viewer library
Group:		System/Libraries
Version:	2.9.1
Release:	%mkrel 2
License:	GPLv2 with exceptions or GPLv3 with exceptions
URL:		https://github.com/GillesDebunne/libQGLViewer
Source0:	https://github.com/GillesDebunne/libQGLViewer/archive/v%{version}/%{softname}-%{version}.tar.gz
# QGLViewer/VRender/gpc.cpp uses exit(0) to "abort" from a failure of malloc
# Use abort() instead.
Patch0:         libQGLViewer-2.9.1-exit.patch
# libQGLViewer .pro files explicitely remove "-g" from compile flags. Make
# them back.
Patch1:         libQGLViewer-2.6.3-dbg.patch
BuildRequires:  pkgconfig(glu)

%description
%{softname} is a C++ library based on Qt that eases the creation of OpenGL
3D viewers. It provides some of the typical 3D viewer functionality, such
as the possibility to move the camera using the mouse, which lacks in most
of the other APIs. Other features include mouse manipulated frames,
interpolated keyFrames, object selection, stereo display, screenshot saving
and much more. It can be used by OpenGL beginners as well as to create
complex applications, being fully customizable and easy to extend.

#------------------------------------------------------------------------------

%define libname_qt5 %mklibname %{packname}-qt5_ %{major}
%define devname_qt5 %mklibname %{packname}-qt5 -d

%package -n	%{libname_qt5}
Summary:	Qt5 based OpenGL generic 3D viewer library
Group:		System/Libraries
BuildRequires:	pkgconfig(Qt5Core)
BuildRequires:	pkgconfig(Qt5Designer)
BuildRequires:	pkgconfig(Qt5Gui)
BuildRequires:	pkgconfig(Qt5OpenGL)
BuildRequires:	pkgconfig(Qt5Widgets)
BuildRequires:	pkgconfig(Qt5Xml)

%description -n	%{libname_qt5}
%{softname} is a C++ library based on Qt5 that eases the creation of OpenGL
3D viewers. It provides some of the typical 3D viewer functionality, such
as the possibility to move the camera using the mouse, which lacks in most
of the other APIs. Other features include mouse manipulated frames,
interpolated keyFrames, object selection, stereo display, screenshot saving
and much more. It can be used by OpenGL beginners as well as to create
complex applications, being fully customizable and easy to extend.

%files	-n	%{libname_qt5}
%doc README LICENCE CHANGELOG GPL_EXCEPTION
%{_libdir}/libQGLViewer-qt5.so.%{major}{,.*}

#------------------------------------------------------------------------------

%package -n	%{devname_qt5}
Summary:	Development files for %{softname}
Group:		Development/KDE and Qt
Requires:	%{libname_qt5} = %{version}-%{release}
Provides:	%{packname}-qt5-devel = %{version}-%{release}
Provides:	lib%{packname}-qt5-devel = %{version}-%{release}

%description -n	%{devname_qt5}
The %{devname_qt5} package contains libraries and header files for
developing applications that use %{softname}.

%files	-n	%{devname_qt5}
%{_qt5_includedir}/QGLViewer/
%{_libdir}/libQGLViewer-qt5.so
%{_libdir}/libQGLViewer-qt5.prl
%{_qt5_plugindir}/designer/libqglviewerplugin.so

#------------------------------------------------------------------------------

%package -n	%{docname}
Summary:	API documentation for %{softname}
Group:		Development/KDE and Qt
Requires:	%{packname}-qt5-devel >= %{version}-%{release}
BuildArch:	noarch

%description -n	%{docname}
API documentation for %{softname}.

%files -n	%{docname}
%doc doc

#------------------------------------------------------------------------------

%prep
%autosetup -p1 -n %{softname}-%{version}

%build
pushd QGLViewer
%qmake_qt5 LIB_DIR=%{_libdir} DOC_DIR=%{_docdir} INCLUDE_DIR=%{_qt5_includedir}
%make_build
popd

pushd designerPlugin
%qmake_qt5 LIB_DIR=../QGLViewer
%make_build
popd

%install
pushd QGLViewer
make -f Makefile -e INSTALL_ROOT=%{buildroot} install_target install_include
popd

pushd designerPlugin
make -e INSTALL_ROOT=%{buildroot} install
popd


%changelog
* Sat Nov 16 2024 daviddavid <daviddavid> 2.9.1-2.mga10
+ Revision: 2116099
- fix dependency on -doc sub-pkg

* Tue Nov 12 2024 daviddavid <daviddavid> 2.9.1-1.mga10
+ Revision: 2114654
- new version: 2.9.1

* Sun Sep 04 2022 pterjan <pterjan> 2.6.4-10.mga9
+ Revision: 1883898
- Drop the qt4 build

* Sun Apr 03 2022 umeabot <umeabot> 2.6.4-9.mga9
+ Revision: 1842124
- Mageia 9 Mass Rebuild

* Thu Dec 17 2020 umeabot <umeabot> 2.6.4-8.mga8
+ Revision: 1658951
- Rebuild for new Qt5

* Sat Feb 15 2020 umeabot <umeabot> 2.6.4-7.mga8
+ Revision: 1527903
- Mageia 8 Mass Rebuild

* Fri Jul 26 2019 daviddavid <daviddavid> 2.6.4-6.mga8
+ Revision: 1424445
- rebuild for new Qt5 headers path

* Sun Mar 31 2019 umeabot <umeabot> 2.6.4-5.mga7
+ Revision: 1383191
- Qt5 Rebuild

* Tue Dec 25 2018 pterjan <pterjan> 2.6.4-4.mga7
+ Revision: 1344933
- Update qreal patch

* Sun Dec 16 2018 pterjan <pterjan> 2.6.4-3.mga7
+ Revision: 1341745
- Add back qreal patch, dropping only what has been already merged in 2.6.4, this should allow to build on arm again

* Sun Sep 23 2018 umeabot <umeabot> 2.6.4-2.mga7
+ Revision: 1299108
- Mageia 7 Mass Rebuild

* Mon Aug 13 2018 daviddavid <daviddavid> 2.6.4-1.mga7
+ Revision: 1251243
- new version: 2.6.4

* Tue Jul 19 2016 daviddavid <daviddavid> 2.6.3-8.mga6
+ Revision: 1042534
- add the support for Qt5

* Sun Jul 17 2016 pterjan <pterjan> 2.6.3-7.mga6
+ Revision: 1042383
- Add missing changes to the qreal patch

* Sun Jul 17 2016 pterjan <pterjan> 2.6.3-6.mga6
+ Revision: 1042374
- Add back line lost in bad merge

* Sun Jul 17 2016 pterjan <pterjan> 2.6.3-5.mga6
+ Revision: 1042365
- Add fedora patch for qreal != double
+ daviddavid <daviddavid>
- fix some packages description

* Sun Jul 17 2016 pterjan <pterjan> 2.6.3-4.mga6
+ Revision: 1042313
- Exclude armv7hl too

* Fri Mar 11 2016 pterjan <pterjan> 2.6.3-3.mga6
+ Revision: 988948
- Exclude armv5tl

* Tue Mar 08 2016 blino <blino> 2.6.3-2.mga6
+ Revision: 987266
- rebuild for armv5tl (also missed in first Mga6 mass rebuild)

* Sun Jan 10 2016 filipesaraiva <filipesaraiva> 2.6.3-1.mga6
+ Revision: 921314
- Update to 2.6.3 version;

* Wed Oct 15 2014 umeabot <umeabot> 2.5.3-3.mga5
+ Revision: 743738
- Second Mageia 5 Mass Rebuild

* Tue Sep 23 2014 wally <wally> 2.5.3-2.mga5
+ Revision: 722236
- add general provides to devel pkg
- fix doc pkg requires

* Mon Sep 22 2014 filipesaraiva <filipesaraiva> 2.5.3-1.mga5
+ Revision: 719168
- Renaming SPEC file
- Renaming libqglviewer package to follow Mageia package policy
- SPEC reviewed;
- Add Obsoletes;
- Fix package name to create i586 version correctly
- Add group to metapackage libQGLViewer
- Update to libQGLViewer 2.5.3 version
- SPEC rewrited to provide i586 packages
+ umeabot <umeabot>
- Mageia 5 Mass Rebuild

* Sun Aug 10 2014 filipesaraiva <filipesaraiva> 2.5.2-1.mga5
+ Revision: 661555
- imported package libQGLViewer

